<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import { ref, computed } from 'vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';

const flashMessage = ref('');
const carmodel = usePage().props.carmodel;
const carMakes = computed(() => usePage().props.carMakes || []);

const form = useForm({
    id: carmodel.id,
    name: carmodel.name,
    year: carmodel.year,
    make: carmodel.make,
});

const years = generateYears(1949, new Date().getFullYear());
const selectedYear = new Date().getFullYear();

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

const reversedYears = computed(() => [...years].reverse());

const submit = () => {
    const carmodelID = carmodel.id;
    form.post(route('admin.product.model.update',{id: carmodelID}), {
        onSuccess: () => {
            flashMessage.value = "Car model updated successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};
</script>

<template>

    <Head title="Edit Model" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Edit Model</h2>
        </template>

        <div class="py-12">

            <div v-if="flashMessage" class="max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-green-600">
                <div class="form-row px-8">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <input type="hidden" id="id" v-model="form.id" />

            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <form @submit.prevent="submit">
                    <div class="form-row px-8">

                        <div class="mt-4 col-md-3">
                            <InputLabel for="year" value="Year" />

                            <select class="w-full mt-1 block border-gray-300 rounded-md" v-model="form.year" id="year" required>
                                <option value="">Select Year</option>
                                <option v-for="year in reversedYears" :key="year" :value="year">{{ year }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.year" />
                        </div>

                        <div class="mt-4 col-md-3">
                            <InputLabel for="name" value="Car Maker" />

                            <select class="w-full mt-1 block border-gray-300 rounded-md" v-model="form.make" id="make" required>
                                <option value="">Select Make</option>
                                <option v-for="make in carMakes" :key="make" :value="make.id">{{ make.name }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.make" />
                        </div>

                        <div class="mt-4 col-md-3">
                            <InputLabel for="name" value="Car Model" />

                            <TextInput
                                id="name"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.name"
                                required
                                autofocus
                                autocomplete="name"
                            />

                            <InputError class="mt-2" :message="form.errors.name" />
                        </div>

                    </div>

                    <div class="flex items-center justify-start my-4 px-8">
                        <PrimaryButton :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Update Model
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
